@@ -1,4 +1,5 @@
 #![allow(dead_code)]
+#![cfg_attr(docsrs, feature(doc_cfg))]
 
 #[cfg(not(any(feature = "runtime-tokio", feature = "runtime-async-std")))]
 compile_error!("one of 'runtime-async-std' or 'runtime-tokio' features must be enabled");
@@ -7,7 +8,7 @@ compile_error!("one of 'runtime-async-std' or 'runtime-tokio' features must be e
 compile_error!("only one of 'runtime-async-std' or 'runtime-tokio' features must be enabled");
 
 // Modules
-pub use sqlx_core::{arguments, decode, describe, encode, error, pool, row, types};
+pub use sqlx_core::{arguments, describe, error, pool, row, types};
 
 // Types
 pub use sqlx_core::{
@@ -21,9 +22,11 @@ pub use sqlx_core::{query, query_as};
 pub use sqlx_core::query_as_mapped;
 
 #[cfg(feature = "mysql")]
+#[cfg_attr(docsrs, doc(cfg(feature = "mysql")))]
 pub use sqlx_core::mysql::{self, MySql, MySqlConnection, MySqlPool};
 
 #[cfg(feature = "postgres")]
+#[cfg_attr(docsrs, doc(cfg(feature = "postgres")))]
 pub use sqlx_core::postgres::{self, PgConnection, PgPool, Postgres};
 
 #[cfg(feature = "macros")]
@@ -31,7 +34,6 @@ pub use sqlx_core::postgres::{self, PgConnection, PgPool, Postgres};
 pub extern crate sqlx_macros;
 
 #[cfg(feature = "macros")]
-#[macro_export]
 mod macros;
 
 // macro support
@@ -42,3 +44,7 @@ pub mod ty_cons;
 #[cfg(feature = "macros")]
 #[doc(hidden)]
 pub mod result_ext;
+
+pub mod encode;
+
+pub mod decode;
